@@ -10,7 +10,7 @@ class TestChangeNotification(unittest.TestCase):
     def test_json_body(self):
         from pyramid_facebook.events import ChangeNotification
 
-        obj = dict(a=123, b=4321)
+        obj = dict(a=123, b=4321, object='payments')
         request = Request(dict(), body=json.dumps(obj))
 
         cn = ChangeNotification(None, request)
